# eric7.QtHelpInterface.HelpIndexWidget

Module implementing a window for showing the QtHelp index.

### Global Attributes

None

### Classes

HelpIndexWidget | Class implementing a window for showing the QtHelp index.

### Functions

None

## HelpIndexWidget

Class implementing a window for showing the QtHelp index.

### Signals

escapePressed()
  emitted when the ESC key was pressed
newBackgroundTab(QUrl, str)
  emitted to open an entry in a new background tab
newTab(QUrl, str)
  emitted to open an entry in a new tab
newWindow(QUrl, str)
  emitted to open an entry in a new window
openUrl(QUrl, str)
  emitted to open an entry in the current tab

### Derived from

QWidget

### Class Attributes

None

### Class Methods

None

### Methods

HelpIndexWidget | Constructor
__disableSearchEdit | Private slot to enable the search edit.
__documentActivated | Private slot to handle the activation of a keyword entry.
__documentsActivated | Private slot to handle the activation of an entry with multiple help documents.
__enableSearchEdit | Private slot to enable the search edit.
__filterIndices | Private slot to filter the indexes according to the given filter.
__selectDocument | Private method to give the user a chance to select among the given documents.
__showContextMenu | Private slot showing the context menu.
eventFilter | Public method called to filter the event queue.
focusInEvent | Protected method handling focus in events.

### Static Methods

None

#### HelpIndexWidget (Constructor)

HelpIndexWidget(engine, internal=False, parent=None)

Constructor

engine (QHelpEngine)
  reference to the help engine
internal (bool)
  flag indicating the internal help viewer
parent (QWidget)
  reference to the parent widget

#### HelpIndexWidget.__disableSearchEdit

__disableSearchEdit()

Private slot to enable the search edit.

#### HelpIndexWidget.__documentActivated

__documentActivated(document, _keyword, modifiers=None)

Private slot to handle the activation of a keyword entry.

document (QHelpLink)
  reference to a data structure containing the document info
_keyword (str)
  keyword for the URL (unused)
modifiers (Qt.KeyboardModifiers or None)
  keyboard modifiers

#### HelpIndexWidget.__documentsActivated

__documentsActivated(documents, helpKeyword)

Private slot to handle the activation of an entry with multiple help documents.

documents (list of QHelpLink)
  list of help document link data structures
helpKeyword (str)
  keyword for the entry

#### HelpIndexWidget.__enableSearchEdit

__enableSearchEdit()

Private slot to enable the search edit.

#### HelpIndexWidget.__filterIndices

__filterIndices(indexFilter)

Private slot to filter the indexes according to the given filter.

indexFilter (str)
  filter to be used

#### HelpIndexWidget.__selectDocument

__selectDocument(documents, helpKeyword)

Private method to give the user a chance to select among the given documents.

documents (list of QHelpLink)
  list of help document link data structures
helpKeyword (str)
  keyword for the documents

Return:
  selected document

Return Type:
  QHelpLink

#### HelpIndexWidget.__showContextMenu

__showContextMenu(pos)

Private slot showing the context menu.

pos (QPoint)
  position to show the menu at

#### HelpIndexWidget.eventFilter

eventFilter(watched, event)

Public method called to filter the event queue.

watched (QObject)
  the QObject being watched
event (QEvent)
  the event that occurred

Return:
  flag indicating whether the event was handled

Return Type:
  bool

#### HelpIndexWidget.focusInEvent

focusInEvent(evt)

Protected method handling focus in events.

evt (QFocusEvent)
  reference to the focus event object

Up